@@ -1,7 +1,3 @@
 from .webscrapers import AmberAlertWebScraper, CustomAlertWebScraper
 
-
-__all__ = [
-    "AmberAlertWebScraper",
-    "CustomAlertWebScraper"
-]
+__all__ = ["AmberAlertWebScraper", "CustomAlertWebScraper"]
